@@ -21,9 +21,11 @@ Constructor
 =cut
 
 sub new {
-    my ($class, $string) = @_;
-    my $self;
-    $self->{_raw_string} = $string;
+    my ($class, $string, $lang) = @_;
+    my $self = {
+                _raw_string => $string,
+                _lang => $lang || 'en',
+               };
     bless $self, $class;
     return $self;
 };
@@ -84,7 +86,7 @@ sub attachments {
 }
 
 sub language_code {
-    return 'en';
+    shift->{_lang};
 }
 
 1;
